@@ -468,7 +468,7 @@ class BankingBackend(GObject.Object):
 
             if client["tan-mechanism"] != "":
                 fints_client.set_tan_mechanism(client["tan-mechanism"])
-            else:
+            elif fints_client.get_tan_mechanisms():
                 event = threading.Event()
                 GLib.idle_add(self.get_mechanism, fints_client, client, event)
                 event.wait()
