@@ -18,11 +18,12 @@ from datetime import datetime, timedelta
 import locale
 
 
-def money(value):
+def money(value: float) -> str:
+    formatted_value = round(value, 2)
     try:
-        return str(locale.currency(value, grouping=True, symbol=False))
+        return str(locale.currency(formatted_value, grouping=True, symbol=False))
     except ValueError:
-        return str(value)
+        return str(formatted_value)
 
 
 def readable_date(date: datetime) -> str:
