@@ -14,12 +14,16 @@ class SqliteCipher:
     Main cipher class
     """
 
-    def __init__(self, database_path="pysqlitecipher.db", check_same_thread=False, password=None):
+    def __init__(
+        self, database_path="pysqlitecipher.db", check_same_thread=False, password=None
+    ):
         self.database_path = database_path
         self.check_same_thread = check_same_thread
 
         # main sqlite3 connection object
-        self.sql_object = sqlite3.connect(database_path, check_same_thread=check_same_thread)
+        self.sql_object = sqlite3.connect(
+            database_path, check_same_thread=check_same_thread
+        )
 
         # password is essential, so it should not be None
         if password is None:
@@ -29,17 +33,25 @@ class SqliteCipher:
         self.password = str(password)
 
         # check if the tableNames table exist in data base if not exist create one and insert it into tableNames table to know that this table exist
-        self.sql_object.execute("CREATE TABLE IF NOT EXISTS tableNames (table_name TEXT, secured INT);")
+        self.sql_object.execute(
+            "CREATE TABLE IF NOT EXISTS tableNames (table_name TEXT, secured INT);"
+        )
         self.sql_object.commit()
 
         if not self.check_table_exist2("tableNames"):
-            self.sql_object.execute("INSERT INTO tableNames (table_name, secured) VALUES ('tableNames', 0);")
+            self.sql_object.execute(
+                "INSERT INTO tableNames (table_name, secured) VALUES ('tableNames', 0);"
+            )
             self.sql_object.commit()
 
         # check if the authenticationTable exist, if not create table
         if not self.check_table_exist2("authenticationTable"):
-            self.sql_object.execute("CREATE TABLE authenticationTable (SHA512_pass TEXT, salt BLOB);")
-            self.sql_object.execute("INSERT INTO tableNames (table_name, secured) VALUES ('authenticationTable', 0);")
+            self.sql_object.execute(
+                "CREATE TABLE authenticationTable (SHA512_pass TEXT, salt BLOB);"
+            )
+            self.sql_object.execute(
+                "INSERT INTO tableNames (table_name, secured) VALUES ('authenticationTable', 0);"
+            )
             self.sql_object.commit()
 
             # converting password to SHA512
@@ -49,21 +61,27 @@ class SqliteCipher:
             salt = os.urandom(16)
 
             # adding sha512 password and encrypted key to data base
-            self.sql_object.execute("INSERT INTO authenticationTable (SHA512_pass, salt) VALUES (?, ?);", [
-                sha512_pass, sqlite3.Binary(salt)])
+            self.sql_object.execute(
+                "INSERT INTO authenticationTable (SHA512_pass, salt) VALUES (?, ?);",
+                [sha512_pass, sqlite3.Binary(salt)],
+            )
             self.sql_object.commit()
         else:
             # validate the password passed to password stored in data base
             # converting password to SHA512
             sha512_pass = hashlib.sha512(self.password.encode()).hexdigest()
             # getting the password from data base
-            cursor_from_sql = self.sql_object.execute("SELECT * FROM authenticationTable;")
+            cursor_from_sql = self.sql_object.execute(
+                "SELECT * FROM authenticationTable;"
+            )
             for i in cursor_from_sql:
                 sha512_pass_from_db = i[0]
 
             # validating and raising error if not match
             if sha512_pass_from_db != sha512_pass:
-                raise RuntimeError("password does not match to password used to create data base")
+                raise RuntimeError(
+                    "password does not match to password used to create data base"
+                )
 
         # getting the encrypted key from db
         cursor_from_sql = self.sql_object.execute("SELECT * FROM authenticationTable;")
@@ -76,10 +94,10 @@ class SqliteCipher:
             length=32,
             salt=salt,
             iterations=480000,
-            backend=default_backend()
+            backend=default_backend(),
         )
 
-        key = base64.urlsafe_b64encode(kdf.derive(bytes(self.password, 'utf-8')))
+        key = base64.urlsafe_b64encode(kdf.derive(bytes(self.password, "utf-8")))
         self.cipher_suite = Fernet(key)
 
         self.md5_pass = hashlib.md5(self.password.encode()).hexdigest()
@@ -116,7 +134,7 @@ class SqliteCipher:
     def check_table_exist(self, table_name):
         """
         Check if a table exist or not
-        :param table_name: Table name to check existance for
+        :param table_name: Table name to check existence for
         :return: %True if found, %False otherwise
         """
         # table name should be only str type
@@ -126,7 +144,9 @@ class SqliteCipher:
         try:
             table_name = str(table_name).strip()
         except ValueError as exc:
-            raise ValueError("Table name passed in check_table_exist function cannot be converted to string") from exc
+            raise ValueError(
+                "Table name passed in check_table_exist function cannot be converted to string"
+            ) from exc
 
         # getting all tablenames in data base
         result = self.sql_object.execute("SELECT * FROM tableNames;")
@@ -151,7 +171,7 @@ class SqliteCipher:
     def check_table_exist2(self, table_name):
         """
         Check if a table exist or not (without match name with secured table)
-        :param table_name: Table name to check existance for
+        :param table_name: Table name to check existence for
         :return: %True if found, %False otherwise
         """
 
@@ -162,7 +182,9 @@ class SqliteCipher:
         try:
             table_name = str(table_name).strip()
         except ValueError as exc:
-            raise ValueError("Table name passed in check_table_exist2 function cannot be converted to string") from exc
+            raise ValueError(
+                "Table name passed in check_table_exist2 function cannot be converted to string"
+            ) from exc
 
         # getting all tablenames in data base
         result = self.sql_object.execute("SELECT * FROM tableNames;")
@@ -257,11 +279,13 @@ class SqliteCipher:
         try:
             table_name = str(table_name).strip()
         except ValueError as exc:
-            raise ValueError("Table name passed in create_table function cannot be converted to string") from exc
+            raise ValueError(
+                "Table name passed in create_table function cannot be converted to string"
+            ) from exc
 
         # collist should not be empty
         if len(col_list) < 1:
-            raise ValueError('col list contains no value in create_table method')
+            raise ValueError("col list contains no value in create_table method")
 
         # table should not exist in database already
         if self.check_table_exist(table_name):
@@ -271,18 +295,24 @@ class SqliteCipher:
         if make_secure:
             table_name = self.encryptor(table_name)
             table_name = "'" + table_name + "'"
-            self.sql_object.execute(f"INSERT INTO tableNames (table_name, secured) VALUES ({table_name}, 1);")
+            self.sql_object.execute(
+                f"INSERT INTO tableNames (table_name, secured) VALUES ({table_name}, 1);"
+            )
         else:
             table_name = "'" + table_name + "'"
-            self.sql_object.execute(f"INSERT INTO tableNames (table_name, secured) VALUES ({table_name}, 0);")
+            self.sql_object.execute(
+                f"INSERT INTO tableNames (table_name, secured) VALUES ({table_name}, 0);"
+            )
 
         # init string to execute in sqlite connector
         # by default a primary key ID is used to perform update, delete operations
-        # this ID is automatically mantained, so no need to pass it in insert list while inserting data to table
+        # this ID is automatically maintained, so no need to pass it in insert list while inserting data to table
         if make_secure:
             string_to_execute = f"CREATE TABLE {table_name} ( '{self.encryptor('ID_I')}' TEXT PRIMARY KEY NOT NULL, "
         else:
-            string_to_execute = f"CREATE TABLE {table_name} ( 'ID_I' TEXT PRIMARY KEY NOT NULL, "
+            string_to_execute = (
+                f"CREATE TABLE {table_name} ( 'ID_I' TEXT PRIMARY KEY NOT NULL, "
+            )
 
         # traverse col list to add colname and data types to string_to_execute
         for i in col_list:
@@ -291,7 +321,7 @@ class SqliteCipher:
 
             colname = i[0]
 
-            # add data type tages to the col names
+            # add data type tags to the col names
             if i[1] == "INT":
                 colname = colname + "_I"
             elif i[1] == "REAL":
@@ -348,7 +378,9 @@ class SqliteCipher:
         try:
             table_name = str(table_name).strip()
         except ValueError as exc:
-            raise ValueError("Table name passed in create_table function cannot be converted to string") from exc
+            raise ValueError(
+                "Table name passed in create_table function cannot be converted to string"
+            ) from exc
 
         # getting all tablenames in data base
         result = self.sql_object.execute("SELECT * FROM tableNames;")
@@ -395,11 +427,16 @@ class SqliteCipher:
             result = self.sql_object.execute(f"SELECT * FROM '{enc_table_name}';")
 
             # decrypting col names if they are encrypted and removing data type tag along with it
-            col_list = [[self.decryptor(description[0])[:-2], description[0]] for description in result.description]
+            col_list = [
+                [self.decryptor(description[0])[:-2], description[0]]
+                for description in result.description
+            ]
         else:
             result = self.sql_object.execute(f"SELECT * FROM '{table_name}';")
 
-            col_list = [[description[0][:-2], None] for description in result.description]
+            col_list = [
+                [description[0][:-2], None] for description in result.description
+            ]
 
         return col_list
 
@@ -414,11 +451,16 @@ class SqliteCipher:
             result = self.sql_object.execute(f"SELECT * FROM '{enc_table_name}';")
 
             # decrypting col names if they are encrypted and removing data type tag along with it
-            col_list = [[self.decryptor(description[0]), description[0]] for description in result.description]
+            col_list = [
+                [self.decryptor(description[0]), description[0]]
+                for description in result.description
+            ]
         else:
             result = self.sql_object.execute(f"SELECT * FROM '{table_name}';")
 
-            col_list = [[description[0], description[0]] for description in result.description]
+            col_list = [
+                [description[0], description[0]] for description in result.description
+            ]
 
         final_col_list = []
 
@@ -476,25 +518,25 @@ class SqliteCipher:
         if secured:
             # if no data in table
             if last_key_from_table is None:
-
                 # init ID as 0
-                last_key_from_table = self.encryptor('0')
+                last_key_from_table = self.encryptor("0")
             else:
-
-                # else get ID, decrypt it, increament it,  encrypt it back
+                # else get ID, decrypt it, increment it,  encrypt it back
                 last_key_from_table = self.decryptor(last_key_from_table)
                 last_key_from_table = int(last_key_from_table) + 1
                 last_key_from_table = self.encryptor(str(last_key_from_table))
         # if table is not secured we just skip encryption and decryption
         else:
             if last_key_from_table is None:
-                last_key_from_table = '0'
+                last_key_from_table = "0"
             else:
                 last_key_from_table = int(last_key_from_table) + 1
                 last_key_from_table = str(last_key_from_table)
 
         # adding the ID value to value list
-        string_to_execute = string_to_execute[:-1] + ") VALUES ( '{}', ".format(last_key_from_table)
+        string_to_execute = string_to_execute[:-1] + ") VALUES ( '{}', ".format(
+            last_key_from_table
+        )
 
         # adding None if the the insert_list as less value than col list
         if len(col_list) - 1 > len(insert_list):
@@ -536,7 +578,9 @@ class SqliteCipher:
         if commit:
             self.sql_object.commit()
 
-    def get_data_from_table(self, table_name, raise_conversion_error=True, omit_id=False, col_type=False):
+    def get_data_from_table(
+        self, table_name, raise_conversion_error=True, omit_id=False, col_type=False
+    ):
         """
         Get the all data from table
         returns two variables
@@ -547,6 +591,7 @@ class SqliteCipher:
         list data type then if raise_conversion_error is True then error is raised
         else the exact string is returned
         """
+
         def raise_conversion_error_function(value, to):
             raise ValueError(f"{value} cannot be converted to {to}")
 
@@ -641,7 +686,9 @@ class SqliteCipher:
 
         return col_list, value_list
 
-    def delete_data_in_table(self, table_name, id_value, commit=True, raise_error=True, update_id=True):
+    def delete_data_in_table(
+        self, table_name, id_value, commit=True, raise_error=True, update_id=True
+    ):
         """
         Delete a row based on ID value
         if raise_error is True, a error will be raised if ID is not found,
@@ -676,7 +723,9 @@ class SqliteCipher:
             if raise_error and not found:
                 raise RuntimeError(f"ID = {id_value} not found while deletion process")
 
-            string_to_execute = f"""DELETE from '{enc_table_name}' where "{id_name}"='{id_value}';"""
+            string_to_execute = (
+                f"""DELETE from '{enc_table_name}' where "{id_name}"='{id_value}';"""
+            )
         else:
             # raise error if ID not found
             if raise_error:
@@ -693,9 +742,13 @@ class SqliteCipher:
 
                 # raise error
                 if not found:
-                    raise RuntimeError(f"ID = {id_value} not found while deletion process")
+                    raise RuntimeError(
+                        f"ID = {id_value} not found while deletion process"
+                    )
 
-            string_to_execute = f"DELETE from '{table_name}' WHERE {id_name}='{id_value}';"
+            string_to_execute = (
+                f"DELETE from '{table_name}' WHERE {id_name}='{id_value}';"
+            )
 
         # exe command
         result = self.sql_object.execute(string_to_execute)
@@ -709,7 +762,6 @@ class SqliteCipher:
             self.sql_object.commit()
 
     def update_ids(self, table_name, commit=True):
-
         # assume ID we total 7 IDS
         # lets say we delete ID = 5 from table then table will still have 0 1 2 3 4 6 ID row, which is not in order
         # we will traverse the data in table and start from 0
@@ -721,7 +773,7 @@ class SqliteCipher:
         count = 0
         for i in result:
             if i[0] != count:
-                self.update_in_table(table_name, i[0], 'ID', count, False)
+                self.update_in_table(table_name, i[0], "ID", count, False)
 
             count = count + 1
 
@@ -729,7 +781,9 @@ class SqliteCipher:
         if commit:
             self.sql_object.commit()
 
-    def update_in_table(self, table_name, id_value, col_name, col_value, commit=True, raise_error=True):
+    def update_in_table(
+        self, table_name, id_value, col_name, col_value, commit=True, raise_error=True
+    ):
         """
         statement to make like
         "UPDATE COMPANY set SALARY = 25000.00 where ID = 1"
@@ -756,7 +810,9 @@ class SqliteCipher:
 
         # raise error if col not found
         if not col_found:
-            raise RuntimeError(f"no such column - {col_name} in table - {table_name} while updating")
+            raise RuntimeError(
+                f"no such column - {col_name} in table - {table_name} while updating"
+            )
 
         # list for binary parameters
         blob_parameters = []
@@ -794,9 +850,17 @@ class SqliteCipher:
                 raise RuntimeError(f"ID = {id_value} not found while deletion process")
 
             if col_data == "BLOB":
-                string_to_execute = """UPDATE '{}' set "{}" = ? where "{}"='{}';""".format(enc_table_name, col_name, id_name, id_value)
+                string_to_execute = (
+                    """UPDATE '{}' set "{}" = ? where "{}"='{}';""".format(
+                        enc_table_name, col_name, id_name, id_value
+                    )
+                )
             else:
-                string_to_execute = """UPDATE '{}' set "{}" = '{}' where "{}"='{}';""".format(enc_table_name, col_name, col_value, id_name, id_value)
+                string_to_execute = (
+                    """UPDATE '{}' set "{}" = '{}' where "{}"='{}';""".format(
+                        enc_table_name, col_name, col_value, id_name, id_value
+                    )
+                )
         else:
             # raise error if ID not found
             if raise_error:
@@ -813,12 +877,22 @@ class SqliteCipher:
 
                 # raise error
                 if not found:
-                    raise RuntimeError("ID = {} not found while deletion process".format(id_value))
+                    raise RuntimeError(
+                        "ID = {} not found while deletion process".format(id_value)
+                    )
 
             if col_data == "BLOB":
-                string_to_execute = """UPDATE '{}' set "{}" = ? where "{}"='{}';""".format(enc_table_name, col_name, id_name, id_value)
+                string_to_execute = (
+                    """UPDATE '{}' set "{}" = ? where "{}"='{}';""".format(
+                        enc_table_name, col_name, id_name, id_value
+                    )
+                )
             else:
-                string_to_execute = """UPDATE '{}' set "{}" = '{}' where "{}"='{}';""".format(table_name, col_name, col_value, id_name, id_value)
+                string_to_execute = (
+                    """UPDATE '{}' set "{}" = '{}' where "{}"='{}';""".format(
+                        table_name, col_name, col_value, id_name, id_value
+                    )
+                )
 
         # exe command
         result = self.sql_object.execute(string_to_execute, blob_parameters)
@@ -848,7 +922,9 @@ class SqliteCipher:
         for i in table_list[2:]:
             _, _, temp_secured = self.check_if_table_is_secured(i[0])
             if temp_secured == 1:
-                col_list, result = self.get_data_from_table(i[0], omit_id=True, col_type=True)
+                col_list, result = self.get_data_from_table(
+                    i[0], omit_id=True, col_type=True
+                )
 
                 table_data.append([i[0], col_list, result])
 
@@ -873,7 +949,9 @@ class SqliteCipher:
         # self.sql_object.commit()
 
         # change the sha512 value
-        string_to_execute = """UPDATE authenticationTable set SHA512_pass = '{}' where SHA512_pass = '{}'""".format(new_sha512_pass, old_sha512_pass)
+        string_to_execute = """UPDATE authenticationTable set SHA512_pass = '{}' where SHA512_pass = '{}'""".format(
+            new_sha512_pass, old_sha512_pass
+        )
         self.sql_object.execute(string_to_execute)
         self.sql_object.commit()
 
@@ -911,11 +989,15 @@ class SqliteCipher:
 
         # raise error if col not found
         if not col_found:
-            raise RuntimeError(f"no such column - {col_name} in table - {table_name} while updating")
+            raise RuntimeError(
+                f"no such column - {col_name} in table - {table_name} while updating"
+            )
 
-        if col_data == 'TEXT':
+        if col_data == "TEXT":
             new_name += "_T"
 
-        string_to_execute = """ALTER TABLE '{}' RENAME COLUMN '{}' TO '{}'""".format(enc_table_name, col_name, self.encryptor(new_name))
+        string_to_execute = """ALTER TABLE '{}' RENAME COLUMN '{}' TO '{}'""".format(
+            enc_table_name, col_name, self.encryptor(new_name)
+        )
         self.sql_object.execute(string_to_execute)
         self.sql_object.commit()
